libHintName property

String? libHintName
final

name of the library to be linked, if null, use target as the library name

This is useful when the target name does not equal to the library name, for example:

target("minimal")
  set_kind("binary")
  add_files("example/main.cpp")
  add_packages("raylib")

In this case, the target name is "minimal", but the library to be used is "raylib".