Xmake class

Constructors

Xmake({required String projectRoot, required CodeConfig codeConfig, Kind kind = .shared, required Logger logger})

Properties

codeConfig → CodeConfig
final
hashCode int
The hash code for this object.
no setterinherited
kind Kind
final
logger → Logger
final
projectRoot String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build({String? target}) Future<void>
call(List<String> args) Future<void>
config() Future<void>
install({String? target, required String installDir}) Future<void>
export the library to the specified directory, and return the path of the installed library file.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited