install method

Future<void> install({
  1. String? target,
  2. required String installDir,
})

export the library to the specified directory, and return the path of the installed library file.

installDir relative to the project root, default is 'dist'

Implementation

Future<void> install({String? target, required String installDir}) =>
    call(['install', '-P', '.', '--installdir=$installDir', ?target]);