XmakeBuilder class
Constructors
- XmakeBuilder({required String target, String? libHintName, required String assetName, required Uri projectRoot, Uri? installDir, required Logger logger, required LinkModeOption linkModeOption})
Properties
- assetName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- installDir → Uri
-
final
- libHintName → String
-
final
- linkModeOption → LinkModeOption
-
final
- logger → Logger
-
final
- projectRoot → Uri
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
{required BuildInput input, required BuildOutputBuilder output}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited