XmakeLibrary class
Constructors
- XmakeLibrary({required String target, String? libHintName, required String assetName, LinkModeOption linkModeOption = .byPreference, Logger? logger})
Properties
- assetName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- libHintName → String?
-
name of the library to be linked, if null, use target as the library name
final
- linkModeOption → LinkModeOption
-
final
- logger → Logger
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → String
-
name of xmake target
final
Methods
-
build(
{required BuildInput input, required BuildOutputBuilder output, Uri? installDir}) → Future< void> -
installDiris the directory where the library will be installed, if null, use$projectRoot/dist -
link(
{required LinkInput input, required LinkOutputBuilder output, LinkerOptions? linkerOptions}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited