install method
export the library to the specified directory, and return the path of the installed library file.
installDir relative to the project root, default is 'dist'
Implementation
Future<void> install({String? target, required String installDir}) =>
call(['install', '-P', '.', '--installdir=$installDir', ?target]);